#[non_exhaustive]pub enum RetryClass {
Never,
SameDevice,
NewDevice,
RecompileSource,
}Expand description
Whether and where a failed workflow may be retried.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Never
Repeating the operation cannot succeed without changing its inputs.
SameDevice
Retry on the same device generation may succeed.
NewDevice
Retry only after acquiring a new device generation.
RecompileSource
Recompile the source graph before retrying.