pub struct AutomataWorklistRequest {
pub worklist_depth: u32,
pub state_visit_count: u64,
pub occupancy_proxy_bps: u16,
pub blocking_active_time_ns: u64,
pub nonblocking_active_time_ns: u64,
}Expand description
Inputs for non-blocking automata worklist policy.
Fields
worklist_depth: u32Current worklist depth in state/index pairs.
state_visit_count: u64Number of state visits measured or planned for this corpus slice.
occupancy_proxy_bps: u16Active-lane or occupancy proxy in basis points.
blocking_active_time_ns: u64Blocking DFA/NFA active time for the same corpus slice.
nonblocking_active_time_ns: u64Non-blocking worklist active time for the same corpus slice.
Implementations