pub enum MegakernelPromotionRoute {
Interpreter,
QueueJit,
OpcodeJit,
WindowJit,
OpcodeAndWindowJit,
}Expand description
Interpreter/JIT promotion route selected from queue and hot-window signals.
Variants
Interpreter
Stay on the generic interpreter path.
QueueJit
Use JIT because the queue is large enough to amortize fused execution.
OpcodeJit
Use JIT because opcode counters crossed the promotion threshold.
WindowJit
Use JIT because repeated descriptor windows crossed the promotion threshold.
OpcodeAndWindowJit
Use JIT because both opcode and window promotion thresholds were crossed.
Implementations