MegakernelQueuePressure

Enum MegakernelQueuePressure 

pub enum MegakernelQueuePressure {
    Empty,
    Light,
    Balanced,
    Saturated,
}
Host-side pressure classification for one megakernel launch.

Variants



Empty

No logical slots are queued.



Light

The queue is below the available worker lanes.



Balanced

The queue is large enough to keep the submitted workers occupied.



Saturated

The queue is several waves deep or already showing requeue pressure.