pub enum PriorityDrainReason {
None,
PendingTelemetry,
RequeueCounterNearLimit,
AgedPromotionCounterNearLimit,
RequeueCounterExhausted,
AgedPromotionCounterExhausted,
}Expand description
Reason a priority scheduler should drain telemetry into a launch request.
Variants
None
No priority telemetry is pending.
PendingTelemetry
Non-empty priority telemetry should be propagated to the policy.
RequeueCounterNearLimit
The requeue counter is inside the configured drain headroom.
AgedPromotionCounterNearLimit
The aged-promotion counter is inside the configured drain headroom.
RequeueCounterExhausted
The requeue counter is exhausted.
AgedPromotionCounterExhausted
The aged-promotion counter is exhausted.
Implementations