#[non_exhaustive]pub enum ProtocolError {
ByteLengthOverflow {
buffer: &'static str,
fix: &'static str,
},
MisalignedByteLength {
buffer: &'static str,
byte_len: usize,
fix: &'static str,
},
MissingWord {
buffer: &'static str,
word_idx: usize,
byte_len: usize,
fix: &'static str,
},
}Expand description
Megakernel host-protocol encoding and decoding error.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ByteLengthOverflow
A requested buffer length overflowed host address space.
MisalignedByteLength
A byte slice is not aligned to full u32 protocol words.
Fields
MissingWord
A requested protocol word is outside the supplied byte slice.