default_priority_offsets_array

Function default_priority_offsets_array 

pub fn default_priority_offsets_array(total_slots: u32) -> [u32; 6]
Encode default priority partition offsets into a fixed array.

Hot callers that immediately write offsets into a control buffer can use this path to avoid allocating the compatibility Vec returned by default_priority_offsets.