Module task

Module task 

Resident task queue ABI for pause, resume, requeue, and priority aging.

Structs

TaskQueueSnapshot
Queue telemetry derived from device-visible continuation task slots.
TaskWorkItem
One device-visible continuation task slot.

Enums

TaskPriority
Priority partition for a continuation task slot.
TaskState
GPU-visible lifecycle state for one continuation task slot.

Constants

TASK_FLAG_PAUSED
Lowest flag bit set when a task voluntarily paused at a continuation point.
TASK_FLAG_REQUEUE_REQUESTED
Flag bit set when a task asked the scheduler to publish it again.
TASK_FLAG_RESUME_READY
Flag bit set when a paused task is eligible to resume.
TASK_FLAG_YIELDED
Flag bit set when a task yielded so another task can run on the same worker.
TASK_SLOT_BYTES
Number of bytes in one continuation task slot.
TASK_SLOT_WORDS
Number of u32 words in one continuation task slot.