pub struct LayeredPromotionReport {
pub events: u64,
pub promoted_layers: u64,
pub promoted_bytes: u64,
pub last_source_layer: u64,
pub last_promoted_layers: u64,
pub last_promoted_bytes: u64,
}Expand description
Layered-cache promotion evidence.
Fields
events: u64Number of lower-layer hit events that caused promotion.
promoted_layers: u64Total faster-layer writes caused by promotion.
promoted_bytes: u64Total artifact bytes copied into faster layers.
last_source_layer: u64Index of the most recent source layer that supplied a promoted hit.
last_promoted_layers: u64Number of faster layers written by the most recent promotion.
last_promoted_bytes: u64Artifact bytes copied by the most recent promotion.