try_complete_io_request

Function try_complete_io_request 

pub fn try_complete_io_request(
    io_queue_bytes: &mut [u8],
    slot_idx: u32,
    success: bool,
) -> Result<(), PipelineError>
Strictly write a completion status for a serviced IO request.

Errors

Returns PipelineError when the target slot is outside the queue byte view, the view is not aligned to complete IO slots, or the view exceeds the compiled poll window.