try_read_epoch

Function try_read_epoch 

pub fn try_read_epoch(control_bytes: &[u8]) -> Result<u32, ProtocolError>
Strictly decode the epoch counter from a control buffer.

Errors

Returns ProtocolError when the buffer is not word-aligned or is too short to contain the epoch word.