try_read_observable

Function try_read_observable 

pub fn try_read_observable(
    control_bytes: &[u8],
    index: u32,
) -> Result<u32, ProtocolError>
Strictly read an observable result word from a control buffer.

Errors

Returns ProtocolError when the buffer is not word-aligned, the index overflows the observable word offset, or the word is outside the buffer.