write_default_priority_offsets

Function write_default_priority_offsets 

pub fn write_default_priority_offsets(
    control_bytes: &mut [u8],
    total_slots: u32,
) -> Result<(), PipelineError>
Write default priority partition offsets into an encoded control buffer.

Errors

Returns PipelineError::QueueFull when the provided control buffer is too short or not aligned to u32 words.