pub struct ResidentWatchdogSnapshot {
pub done_delta: u32,
pub queue_depth: u32,
pub fault_slots: u32,
pub requeue_slots: u32,
pub gpu_idle_ppm: u32,
pub suspected_stall: bool,
}Expand description
Watchdog view computed from two host-visible telemetry snapshots.
Fields
done_delta: u32Increase in drained slots between the previous and current snapshot.
queue_depth: u32Current active queue depth.
fault_slots: u32Current faulted slots.
requeue_slots: u32Current requeued slots.
gpu_idle_ppm: u32Current idle slots in parts per million.
suspected_stall: boolTrue when work remains queued but no drain progress was observed.