Resident task queue ABI for pause, resume, requeue, and priority aging.
Structs
- Task
Queue Snapshot - Queue telemetry derived from device-visible continuation task slots.
- Task
Work Item - One device-visible continuation task slot.
Enums
- Task
Priority - Priority partition for a continuation task slot.
- Task
State - GPU-visible lifecycle state for one continuation task slot.
Constants
- TASK_
FLAG_ PAUSED - Lowest flag bit set when a task voluntarily paused at a continuation point.
- TASK_
FLAG_ REQUEUE_ REQUESTED - Flag bit set when a task asked the scheduler to publish it again.
- TASK_
FLAG_ RESUME_ READY - Flag bit set when a paused task is eligible to resume.
- TASK_
FLAG_ YIELDED - Flag bit set when a task yielded so another task can run on the same worker.
- TASK_
SLOT_ BYTES - Number of bytes in one continuation task slot.
- TASK_
SLOT_ WORDS - Number of
u32words in one continuation task slot.